# PIPEWIRE INSTALLATION 

## Ubuntu +20.04


1. Install pipewire via PPA:<br> `sudo add-apt-repository ppa:pipewire-debian/pipewire-upstream` <br> `sudo apt install pipewire`

https://github.com/pipewire-debian/pipewire-debian


2. Reboot your computer or laptop
3. [OPTIONAL] Install `pavucontrol` without pulseaudio: <br>`sudo apt-get install --no-install-recommends pavucontrol`
4. Reboot and change configs in `pavucontrol` to `Pro Audio`

 ![](https://imgur.com/514XIgR.png)
